
***************************
* File: A_centre_sante.do 
* Questionnaire type: Health Facility
* Country: Madagascar
*****************************

version 10.1
cd "Source\Madagascar 2006 P H\"
capture clear
capture log close
clear
set mem 700m
set more off

use "Source\First Round\csb_2e_jour\A_centre_sante.dta"

**************************************************
***    Ensure all variables are present and labeled.
**************************************************
cd "Source\First Round\csb_2e_jour"
log using "A_centre_sante", replace
codebook, compact
log close

**************************************************
***   Ensure response value labels are correct.
**************************************************
label save using "A_centre_sante label values", replace

**************************************************
***   Unique identifiers: ID
**************************************************
local mylist " disponibl non_disp rsn_nodisp avant rupture qte unite prix"
levelsof  typ_med, local( typ_med_levels)
foreach v of varlist disponibl non_disp rsn_nodisp avant rupture qte unite prix{
local l`v' : variable label `v'
}
reshape wide disponibl non_disp rsn_nodisp avant rupture qte unite prix , i( code_cs) j( typ_med)
foreach x of local mylist{
foreach y of local  typ_med_levels{
label var `x'`y' "`l`x''"
}
}

**************************************************
***   Recode missing values
***************************************************

*    DECODE MISSING VALUES
# d ;
qui mvdecode  indigent, mv(
999=.d);
# d cr;

**************************************************
***    Identify skip patterns
**************************************************
* Recode missing values to Stata missing values, for tests and data inspection.
quietly mvdecode _all,mv (-666 = .d \ -777 = .n \ -888 = .l \ -999 = .r) 

foreach v of varlist     source dist_source tps_source{
	gen error01`v' = (eau == 2 & `v'< . )
}
 
foreach v of varlist    heur_gen heur_pub{
	gen error01`v' = (electri == 2 & `v'< . )
}

foreach v of varlist    voiture ambulance moto bicycle charrette{
	gen error01`v' = (transport ==2& `v'< . )
}

foreach v of varlist     type_toil{
	gen error01`v' = (toilette == 2 & `v'< . )
}

foreach v of varlist   dern_visite nb_visites{
	gen error01`v' = ( vis_inspect == 2 & `v'< . )
}

foreach v of varlist    rem_par paie_regul{
	gen error01`v' = (remunere == 2 & `v'< . )
}

foreach v of varlist    nb_mb_cosan fok_cosan chefok_cosan reun_cosan per_reun{
	gen error01`v' = ( cosan == 2 & `v'< . )
}

 foreach v of varlist   lieu_affiche{
	gen error01`v' = (dep_affiche == 2 & `v'< . )
}

foreach v of varlist   aut_dep1{
	gen error01`v' = (  fe_mois1 == 2 & `v'< . )
}

**************************************************
***    Identify illegal responses
**************************************************

log using "A_centre_sante label inspect", replace
inspect
log close

**************************************************
***    Identify outliers
**************************************************

log using "A_centre_sante grubbs", replace
preserve
global discrete ( eau	electri	transport	telephone	radio	toilette	vis_inspect	fanome	coge_fanome	reun_coge	confl_coge	reun_maire	confl_maire	remunere paie_regul	cosan	fok_cosan	fiche_fanome	dep_affiche	compta	source	ordure	type_toil	choix_indig	per_indig	rem_par	nomination	per_reun	lieu_affiche	fonds_equite	sinon)
drop $discrete $name 
mvdecode _all, mv(0 = .z)
grubbs _all, level(99.99)
sum grubbs*
drop grubbs* 
mvencode _all, mv(.z = 0)
log close
restore

**************************************************
***   Identify errors to be reviewed
**************************************************

replace  nb_visites=. if code_cs== 1140512 | code_cs==2071312

**************************************************
***   Reviewing errors and computing responses
**************************************************
drop err* 

**************************************************
*** FINAL   : Delivrables
**************************************************

*Codebook
cd "Source\4- Data\4.3. Clean Data\4.3.3. Data Code Book\First Round\csb_2e_jour"
log using "A_centre_sante codebook", replace
codebook, compact
log close

*Save cleaned data
cd "Source\4- Data\4.3. Clean Data\4.3.1. Final Data\First Round\csb_2e_jour"
save A_centre_sante_cleaned_data.dta, replace
