
***************************
* File: C1_situation_medicaments.do 
* Questionnaire type: Health Facility
* Country: Madagascar
*****************************

version 10.1
cd "Source\Madagascar 2006 P H\"
capture clear
capture log close
clear
set mem 700m
set more off


use "Source\4.1 Raw Data\First Round\csb_2e_jour\C1_situation_medicaments.dta"

*Duplicates
sort  code_cs typ_med 
quietly by  code_cs typ_med: gen dup = cond(_N==1,0,_n)
foreach v of varlist disponibl non_disp rsn_nodisp avant rupture qte  prix{
replace `v' =. if dup>0
}
foreach v of varlist unite{
replace `v' ="." if dup>0
}
drop if dup==2
drop dup

local mylist " disponibl non_disp rsn_nodisp avant rupture qte unite prix"
levelsof  typ_med, local( typ_med_levels)
foreach v of varlist disponibl non_disp rsn_nodisp avant rupture qte unite prix{
local l`v' : variable label `v'
}
reshape wide disponibl non_disp rsn_nodisp avant rupture qte unite prix , i( code_cs) j( typ_med)
foreach x of local mylist{
foreach y of local  typ_med_levels{
label var `x'`y' "`l`x''"
}
}


**************************************************
***  Ensure all variables are present and labeled.
**************************************************
cd "Source\First Round\csb_2e_jour"
log using "C1_situation_medicaments", replace
codebook, compact
log close

**************************************************
***    Ensure response value labels are correct.
**************************************************
label save using "C1_situation_medicaments label values", replace

**************************************************
***    Identify skip patterns
**************************************************
* Recode missing values to Stata missing values, for tests and data inspection.
quietly mvdecode _all,mv (-666 = .d \ -777 = .n \ -888 = .l \ -999 = .r) 
 
foreach v of varlist   non_disp1 rsn_nodisp1{
	gen error01`v' = (disponibl1== 1 & `v'== . )
}

foreach v of varlist   non_disp2 rsn_nodisp2{
	gen error01`v' = (disponibl2== 1 & `v'==  . )
}

foreach v of varlist   non_disp3 rsn_nodisp3{
	gen error01`v' = (disponibl3== 1 & `v'< . )
}

foreach v of varlist   non_disp4 rsn_nodisp4{
	gen error01`v' = (disponibl4== 1 & `v'< . )
}

foreach v of varlist   non_disp5 rsn_nodisp5{
	gen error01`v' = (disponibl5== 1 & `v'< . )
}

foreach v of varlist   non_disp6 rsn_nodisp6{
	gen error01`v' = (disponibl6== 1 & `v'< . )
}

foreach v of varlist   non_disp7 rsn_nodisp7{
	gen error01`v' = (disponibl7== 1 & `v'< . )
}

foreach v of varlist   non_disp8 rsn_nodisp8{
	gen error01`v' = (disponibl8== 1 & `v'< . )
}
 
 foreach v of varlist   non_disp9 rsn_nodisp9{
	gen error01`v' = (disponibl9== 1 & `v'< . )
}

foreach v of varlist   non_disp10 rsn_nodisp10{
	gen error01`v' = (disponibl10== 1 & `v'< . )
}

foreach v of varlist   non_disp11 rsn_nodisp11{
	gen error01`v' = (disponibl11== 1 & `v'< . )
}
foreach v of varlist   non_disp12 rsn_nodisp12{
	gen error01`v' = (disponibl2== 1 & `v'< . )
}

foreach v of varlist   non_disp13 rsn_nodisp13{
	gen error01`v' = (disponibl13== 1 & `v'< . )
}

foreach v of varlist   non_disp14 rsn_nodisp14{
	gen error01`v' = (disponibl14== 1 & `v'< . )
}

foreach v of varlist   non_disp15 rsn_nodisp15{
	gen error01`v' = (disponibl15== 1 & `v'< . )
}

foreach v of varlist   non_disp16 rsn_nodisp16{
	gen error01`v' = (disponibl16== 1 & `v'< . )
}

foreach v of varlist   non_disp17 rsn_nodisp17{
	gen error01`v' = (disponibl17== 1 & `v'< . )
}

foreach v of varlist   non_disp18 rsn_nodisp18{
	gen error01`v' = (disponibl18== 1 & `v'< . )
}
 
 foreach v of varlist   non_disp19 rsn_nodisp19{
	gen error01`v' = (disponibl19== 1 & `v'< . )
}


foreach v of varlist   non_disp20 rsn_nodisp20{
	gen error01`v' = (disponibl20== 1 & `v'< . )
}

foreach v of varlist   non_disp21 rsn_nodisp21{
	gen error01`v' = (disponibl21== 1 & `v'< . )
}



foreach v of varlist   rupture1 {
	gen error02`v' = (avant1== 1 & `v'== . )
}

foreach v of varlist   rupture2 {
	gen error02`v' = (avant2== 1 & `v'==  . )
}

foreach v of varlist   rupture3 {
	gen error02`v' = (avant3== 1 & `v'< . )
}

foreach v of varlist   rupture4 {
	gen error02`v' = (avant4== 1 & `v'< . )
}

foreach v of varlist   rupture5 {
	gen error02`v' = (avant5== 1 & `v'< . )
}

foreach v of varlist   rupture6 {
	gen error02`v' = (avant6== 1 & `v'< . )
}

foreach v of varlist   rupture7 {
	gen error02`v' = (avant7== 1 & `v'< . )
}

foreach v of varlist   rupture8 {
	gen error02`v' = (avant8== 1 & `v'< . )
}
 
 foreach v of varlist   rupture9 {
	gen error02`v' = (avant9== 1 & `v'< . )
}

foreach v of varlist   rupture10 {
	gen error02`v' = (avant10== 1 & `v'< . )
}

foreach v of varlist   rupture11 {
	gen error02`v' = (avant11== 1 & `v'< . )
}
foreach v of varlist   rupture12 {
	gen error02`v' = (avant2== 1 & `v'< . )
}

foreach v of varlist   rupture13 {
	gen error02`v' = (avant13== 1 & `v'< . )
}

foreach v of varlist   rupture14 {
	gen error02`v' = (avant14== 1 & `v'< . )
}

foreach v of varlist   rupture15 {
	gen error02`v' = (avant15== 1 & `v'< . )
}

foreach v of varlist   rupture16 {
	gen error02`v' = (avant16== 1 & `v'< . )
}

foreach v of varlist   rupture17 {
	gen error02`v' = (avant17== 1 & `v'< . )
}

foreach v of varlist   rupture18 {
	gen error02`v' = (avant18== 1 & `v'< . )
}
 
 foreach v of varlist   rupture19 {
	gen error02`v' = (avant19== 1 & `v'< . )
}


foreach v of varlist   rupture20 {
	gen error02`v' = (avant20== 1 & `v'< . )
}

foreach v of varlist   rupture21 {
	gen error02`v' = (avant21== 1 & `v'< . )
}


**************************************************
***   Identify illegal responses
**************************************************

log using "C1_situation_medicaments label inspect", replace
inspect
log close


**************************************************
***    Identify outliers
**************************************************


log using "C1_situation_medicaments grubbs", replace
preserve
global name (unite*)
global discrete ( rsn_nodisp*	avant*	disponibl*)
drop $discrete  $name
mvdecode _all, mv(0 = .z)
grubbs _all, level(99.99)
sum grubbs*
drop grubbs* 
mvencode _all, mv(.z = 0)
log close
restore

**************************************************
***  Reviewing errors and computing responses
**************************************************
replace disponibl20=2 if  code_cs==1120511
replace avant1=2 if  code_cs==4060911
replace rupture3=. if  code_cs==3145512
replace rupture4=. if  code_cs==3145512
replace avant5=2 if  code_cs==2052712
replace avant7=2 if  code_cs==2050511
replace avant7=2 if  code_cs==4020211
replace avant8=2 if  code_cs==4020211
replace avant8=2 if  code_cs==4061111
replace avant8=2 if  code_cs==4091111
replace avant9=2 if  code_cs==4060911
replace avant10=2 if  code_cs==2070512
replace avant11=2 if  code_cs==2070512
replace avant12=2 if  code_cs==4020211
replace avant13=2 if  code_cs==2070512
replace avant15=2 if  code_cs==1031312
replace avant15=2 if  code_cs==2134111
replace avant15=2 if  code_cs==7191912
replace avant16=2 if  code_cs==2050912
replace avant16=2 if  code_cs==2070512
replace avant16=2 if  code_cs==7191912
replace avant17=2 if  code_cs==2134111
replace avant19=2 if  code_cs==1063711
replace avant19=2 if  code_cs==2134312
replace avant20=2 if  code_cs==2050512
replace avant20=2 if  code_cs==2134312
replace avant21=2 if  code_cs==2052712

drop err* 

**************************************************
*** FINAL   : Delivrables
**************************************************

*Codebook
cd "Source\4- Data\4.3. Clean Data\4.3.3. Data Code Book\First Round\csb_2e_jour"
log using "C1_situation_medicaments codebook", replace
codebook, compact
log close

*Save cleaned data
cd "Source\4- Data\4.3. Clean Data\4.3.1. Final Data\First Round\csb_2e_jour"
save C1_situation_medicaments_cleaned_data.dta, replace
