
***************************
* File: A_centre_sante.do 
* Questionnaire type: Health Facility
* Country: Madagascar
*****************************

version 10.1
cd "Source\Madagascar 2006 P H\"
capture clear
capture log close
clear
set mem 700m
set more off


use "Source\4- Data\4.1 Raw Data\First Round\csb_2e_jour\C2_situation_derniere_livraison.dta"

**************************************************
***   Ensure all variables are present and labeled.
**************************************************
cd "Source\First Round\csb_2e_jour"
log using "C2_situation_derniere_livraison", replace
codebook, compact
log close

**************************************************
***   Ensure response value labels are correct.
**************************************************
label save using "C2_situation_derniere_livraison", replace

**************************************************
***    Unique identifiers: ID
**************************************************
local mylist " condition unite qte_com1 prix1 qte_liv1 valeur1 qte_com2 prix2 qte_liv2 valeur2"
levelsof  typ_med, local( typ_med_levels)
foreach v of varlist condition unite qte_com1 prix1 qte_liv1 valeur1 qte_com2 prix2 qte_liv2 valeur2{
local l`v' : variable label `v'
}
reshape wide condition unite qte_com1 prix1 qte_liv1 valeur1 qte_com2 prix2 qte_liv2 valeur2, i( code_cs) j( typ_med)
foreach x of local mylist{
foreach y of local  typ_med_levels{
label var `x'`y' "`l`x''"
}
}


**************************************************
***    Identify skip patterns
**************************************************
* Recode missing values to Stata missing values, for tests and data inspection.
quietly mvdecode _all,mv (-666 = .d \ -777 = .n \ -888 = .l \ -999 = .r) 

**************************************************
***  : Identify illegal responses
**************************************************

log using "C2_situation_derniere_livraison label inspect", replace
inspect
log close

**************************************************
***    Identify outliers
**************************************************

log using "C2_situation_derniere_livraison grubbs", replace
preserve
global name (unite*)
drop  $name 
mvdecode _all, mv(0 = .z)
grubbs _all, level(99.99)
sum grubbs*
drop grubbs* 
mvencode _all, mv(.z = 0)
log close
restore

**************************************************
*** FINAL   : Delivrables
**************************************************

*Codebook
cd "Source\4- Data\4.3. Clean Data\4.3.3. Data Code Book\First Round\csb_2e_jour"
log using "C2_situation_derniere_livraison codebook", replace
codebook, compact
log close

*Save cleaned data
cd "Source\Madagascar 2006 P H\4- Data\4.3. Clean Data\4.3.1. Final Data\First Round\csb_2e_jour"
save C2_situation_derniere_livraison_cleaned_data.dta, replace
